==> testsuite-3.0.61-beta1.tar.gz: testsuite/modules/list_packages/src/Form/ListLibrariesFilterForm.php <==
<?php

namespace Drupal\list_packages\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the database logging filter form.
 *
 * @internal
 */
class ListLibrariesFilterForm extends FormBase {

  /**
   * The array of filters.
   *
   * @var array
   */
  private $filters = [
    'type',
    'if_vulnerability',
  ];

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'list_libraries_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $filters = list_libraries_filters();

    $session_filters = $this->getRequest()->getSession()->get('list_libraries_overview_filter', []);

    $form['filters'] = [
      '#type' => 'details',
      '#title' => $this->t('Filter log messages'),
      '#description' => $this->t('Select Load Libraries and click Save to load all installed libraries. Select Filter and a Vendor then click save to filter the list. To create another search you must first click Reset.'),
      '#open' => TRUE,
      '#attached' => [
        'library' => [
          'testsuite/testsuite.filters',
        ],
      ],
    ];

    $form['filters']['filters-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-filter-form-wrapper',
      ],
    ];

    $ifVulnerabilityDropdown = $form_state->hasValue('if_vulnerability') ? $form_state->getValue('if_vulnerability') : '';
    $if_vulnerability_dropdown = $session_filters['if_vulnerability'] ?? $ifVulnerabilityDropdown;

    $form['filters']['filters-container']['if-vulnerabilities-container'] = [
      '#type' => 'container',
    ];
    $form['filters']['filters-container']['if-vulnerabilities-container']['if_vulnerability'] = [
      '#title' => 'If Vulnerability',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        0 => $this->t('Vulnerabilities'),
        1 => $this->t('Not Definative'),
        2 => $this->t('No Information'),
        3 => $this->t('No Vulnerabilities'),
        4 => $this->t('Internal Scripts'),
      ],
      '#default_value' => $if_vulnerability_dropdown,
    ];

    $typeDropdown = $form_state->hasValue('type') ? $form_state->getValue('type') : '';
    $type_dropdown = !empty($session_filters['type']) ? $session_filters['type'] : $typeDropdown;

    $form['filters']['filters-container']['type-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-types-container',
      ],
    ];
    $form['filters']['filters-container']['type-container']['type'] = [
      '#title' => 'Package Type',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => $filters['type']['options'] ?? "",
      '#default_value' => $type_dropdown,
    ];

    $form['filters']['actions'] = [
      '#type' => 'actions',
      '#attributes' => ['class' => ['container-inline']],
    ];
    $form['filters']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];
    if (!empty($session_filters)) {
      $form['filters']['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#limit_validation_errors' => [],
        '#submit' => ['::resetForm'],
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!in_array($form_state->getValue('type'), [
      '',
      'composer',
      'package',
      'other',
    ])) {
      $form_state->setErrorByName('type', $this->t('Invalid option.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('list_libraries_overview_filter', []);

    foreach ($this->filters as $name) {
      if ($form_state->hasValue($name)) {
        $session_filters[$name] = $form_state->getValue($name);
      }
    }
    $this->getRequest()->getSession()->set('list_libraries_overview_filter', $session_filters);
  }

  /**
   * Resets the filter form.
   */
  public function resetForm() {
    $this->getRequest()->getSession()->remove('list_libraries_overview_filter');
  }

}

==> testsuite-3.0.67-beta1.tar.gz: testsuite/modules/list_packages/src/Form/ListLibrariesFilterForm.php <==
<?php

namespace Drupal\list_packages\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the database logging filter form.
 *
 * @internal
 */
class ListLibrariesFilterForm extends FormBase {

  /**
   * The array of filters.
   *
   * @var array
   */
  private $filters = [
    'type',
    'if_vulnerability',
  ];

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'list_libraries_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $filters = list_packages_libraries_filters();

    $session_filters = $this->getRequest()->getSession()->get('list_libraries_overview_filter', []);

    $form['filters'] = [
      '#type' => 'details',
      '#title' => $this->t('Filter log messages'),
      '#description' => $this->t('Select Load Libraries and click Save to load all installed libraries. Select Filter and a Vendor then click save to filter the list. To create another search you must first click Reset.'),
      '#open' => TRUE,
      '#attached' => [
        'library' => [
          'testsuite/testsuite.filters',
        ],
      ],
    ];

    $form['filters']['filters-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-filter-form-wrapper',
      ],
    ];

    $ifVulnerabilityDropdown = $form_state->hasValue('if_vulnerability') ? $form_state->getValue('if_vulnerability') : '';
    $if_vulnerability_dropdown = $session_filters['if_vulnerability'] ?? $ifVulnerabilityDropdown;

    $form['filters']['filters-container']['if-vulnerabilities-container'] = [
      '#type' => 'container',
    ];
    $form['filters']['filters-container']['if-vulnerabilities-container']['if_vulnerability'] = [
      '#title' => 'If Vulnerability',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        0 => $this->t('Vulnerabilities'),
        1 => $this->t('Not Definative'),
        2 => $this->t('No Information'),
        3 => $this->t('No Vulnerabilities'),
        4 => $this->t('Internal Scripts'),
      ],
      '#default_value' => $if_vulnerability_dropdown,
    ];

    $typeDropdown = $form_state->hasValue('type') ? $form_state->getValue('type') : '';
    $type_dropdown = !empty($session_filters['type']) ? $session_filters['type'] : $typeDropdown;

    $form['filters']['filters-container']['type-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-types-container',
      ],
    ];
    $form['filters']['filters-container']['type-container']['type'] = [
      '#title' => 'Package Type',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => $filters['type']['options'] ?? "",
      '#default_value' => $type_dropdown,
    ];

    $form['filters']['actions'] = [
      '#type' => 'actions',
      '#attributes' => ['class' => ['container-inline']],
    ];
    $form['filters']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];
    if (!empty($session_filters)) {
      $form['filters']['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#limit_validation_errors' => [],
        '#submit' => ['::resetForm'],
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!in_array($form_state->getValue('type'), [
      '',
      'composer',
      'package',
      'other',
    ])) {
      $form_state->setErrorByName('type', $this->t('Invalid option.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('list_libraries_overview_filter', []);

    foreach ($this->filters as $name) {
      if ($form_state->hasValue($name)) {
        $session_filters[$name] = $form_state->getValue($name);
      }
    }
    $this->getRequest()->getSession()->set('list_libraries_overview_filter', $session_filters);
  }

  /**
   * Resets the filter form.
   */
  public function resetForm() {
    $this->getRequest()->getSession()->remove('list_libraries_overview_filter');
  }

}
